@@ -80,8 +80,8 @@ EventParameterDialog::EventParameterDialog(
     text = i18n("Ringing - set %1 alternating from max to min with both dying to zero").arg(strtoqstr(property));
     m_patternCombo->insertItem(text);
 
-    connect(m_patternCombo, TQT_SIGNAL(activated(int)),
-            this, TQT_SLOT(slotPatternSelected(int)));
+    connect(m_patternCombo, TQ_SIGNAL(activated(int)),
+            this, TQ_SLOT(slotPatternSelected(int)));
 
     TQHBox *value1Box = new TQHBox(vBox);
     m_value1Label = new TQLabel(i18n("Value"), value1Box);
