@@ -61,7 +61,7 @@
 #include <tdeconfig.h>
 #include <tdelocale.h>
 #include <kstatusbar.h>
-#include <kstddirs.h>
+#include <kstandarddirs.h>
 #include <tdeglobal.h>
 #include <klineeditdlg.h>
 #include <tdelistview.h>
