@@ -25,7 +25,7 @@
 
 #include "base/BaseProperties.h"
 #include <tdelocale.h>
-#include <kstddirs.h>
+#include <kstandarddirs.h>
 #include "base/Event.h"
 #include "base/NotationTypes.h"
 #include "base/SegmentMatrixHelper.h"
