@@ -69,68 +69,68 @@ NotationSelector::NotationSelector(NotationView* view)
         m_justSelectedBar(false),
         m_wholeStaffSelectionComplete(false)
 {
-    connect(m_parentView, TQT_SIGNAL(usedSelection()),
-            this, TQT_SLOT(slotHideSelection()));
+    connect(m_parentView, TQ_SIGNAL(usedSelection()),
+            this, TQ_SLOT(slotHideSelection()));
 
-    connect(this, TQT_SIGNAL(editElement(NotationStaff *, NotationElement *, bool)),
-            m_parentView, TQT_SLOT(slotEditElement(NotationStaff *, NotationElement *, bool)));
+    connect(this, TQ_SIGNAL(editElement(NotationStaff *, NotationElement *, bool)),
+            m_parentView, TQ_SLOT(slotEditElement(NotationStaff *, NotationElement *, bool)));
 
     TQIconSet icon
     (NotePixmapFactory::toTQPixmap(NotePixmapFactory::
                                   makeToolbarPixmap("crotchet")));
     new TDEToggleAction(i18n("Switch to Insert Tool"), icon, 0, this,
-                      TQT_SLOT(slotInsertSelected()), actionCollection(),
+                      TQ_SLOT(slotInsertSelected()), actionCollection(),
                       "insert");
 
     new TDEAction(i18n("Switch to Erase Tool"), "eraser", 0, this,
-                TQT_SLOT(slotEraseSelected()), actionCollection(),
+                TQ_SLOT(slotEraseSelected()), actionCollection(),
                 "erase");
 
     // (this crashed, and it might be superfluous with ^N anyway, so I'm
     // commenting it out, but leaving it here in case I change my mind about
     // fooling with it.)  (DMM)
     //    new TDEAction(i18n("Normalize Rests"), 0, 0, this,
-    //                TQT_SLOT(slotCollapseRests()), actionCollection(),
+    //                TQ_SLOT(slotCollapseRests()), actionCollection(),
     //                "collapse_rests");
 
     new TDEAction(i18n("Collapse Rests"), 0, 0, this,
-                TQT_SLOT(slotCollapseRestsHard()), actionCollection(),
+                TQ_SLOT(slotCollapseRestsHard()), actionCollection(),
                 "collapse_rests_aggressively");
 
     new TDEAction(i18n("Respell as Flat"), 0, 0, this,
-                TQT_SLOT(slotRespellFlat()), actionCollection(),
+                TQ_SLOT(slotRespellFlat()), actionCollection(),
                 "respell_flat");
 
     new TDEAction(i18n("Respell as Sharp"), 0, 0, this,
-                TQT_SLOT(slotRespellSharp()), actionCollection(),
+                TQ_SLOT(slotRespellSharp()), actionCollection(),
                 "respell_sharp");
 
     new TDEAction(i18n("Respell as Natural"), 0, 0, this,
-                TQT_SLOT(slotRespellNatural()), actionCollection(),
+                TQ_SLOT(slotRespellNatural()), actionCollection(),
                 "respell_natural");
 
     new TDEAction(i18n("Collapse Notes"), 0, 0, this,
-                TQT_SLOT(slotCollapseNotes()), actionCollection(),
+                TQ_SLOT(slotCollapseNotes()), actionCollection(),
                 "collapse_notes");
 
     new TDEAction(i18n("Interpret"), 0, 0, this,
-                TQT_SLOT(slotInterpret()), actionCollection(),
+                TQ_SLOT(slotInterpret()), actionCollection(),
                 "interpret");
 
     new TDEAction(i18n("Move to Staff Above"), 0, 0, this,
-                TQT_SLOT(slotStaffAbove()), actionCollection(),
+                TQ_SLOT(slotStaffAbove()), actionCollection(),
                 "move_events_up_staff");
 
     new TDEAction(i18n("Move to Staff Below"), 0, 0, this,
-                TQT_SLOT(slotStaffBelow()), actionCollection(),
+                TQ_SLOT(slotStaffBelow()), actionCollection(),
                 "move_events_down_staff");
 
     new TDEAction(i18n("Make Invisible"), 0, 0, this,
-                TQT_SLOT(slotMakeInvisible()), actionCollection(),
+                TQ_SLOT(slotMakeInvisible()), actionCollection(),
                 "make_invisible");
 
     new TDEAction(i18n("Make Visible"), 0, 0, this,
-                TQT_SLOT(slotMakeVisible()), actionCollection(),
+                TQ_SLOT(slotMakeVisible()), actionCollection(),
                 "make_visible");
 
     createMenu("notationselector.rc");
@@ -256,7 +256,7 @@ void NotationSelector::handleMouseDoubleClick(timeT,
 
         m_justSelectedBar = true;
         TQTimer::singleShot(TQApplication::doubleClickInterval(), this,
-                           TQT_SLOT(slotClickTimeout()));
+                           TQ_SLOT(slotClickTimeout()));
     }
 
     return ;
