@@ -27,7 +27,7 @@
 #include <tdeapplication.h>
 
 #include <tdelocale.h>
-#include <kstddirs.h>
+#include <kstandarddirs.h>
 #include <tdestdaccel.h>
 #include <tdeconfig.h>
 #include "misc/Debug.h"
