@@ -82,7 +82,7 @@ PitchDragLabel::slotSetPitch(int pitch, int octave, int step)
 void
 PitchDragLabel::mousePressEvent(TQMouseEvent *e)
 {
-    if (e->button() == Qt::LeftButton) {
+    if (e->button() == TQt::LeftButton) {
         m_clickedY = e->y();
         m_clickedPitch = m_pitch;
         m_clicked = true;
