@@ -98,7 +98,7 @@ public:
 
     struct NoteOffEventCmp
     {
-        bool operator()(NoteOffEvent *nO1, NoteOffEvent *nO2)
+        bool operator()(NoteOffEvent *nO1, NoteOffEvent *nO2) const
         {
             return nO1->getRealTime() < nO2->getRealTime();
         }
